# 5分钟学会粤语编程
本教程为粤语的快餐教程, 来不及解释了，快上车! 

## 第一条语句: 畀我睇下 ... 点样先?
还记得第一个程序`HelloWorld`吗?
```
畀我睇下 " Hello World " 点样先?
```
这里的`畀`(bei)在粤语中是给的意思，`睇`不难猜出是`看`的意思，所以整条语句的意思是`让我看看`的意思, 而后面的`点样先?`则表示委婉的语气，意为`怎么样`。虽然计算机是我们的奴隶，但是我们还是需要用委婉语气来给计算机留下第一个好的印象，否则计算机可能会离家出走呢，对吧？  

## 讲嘢: ... 係 ...
```
讲嘢: |A| 係 1
```
这条语句相当于`A := 1`, 当然你也可以去掉`|...|`，尽管这样做不美观。  
这里的`讲嘢`是`说话`的意思, `係`就是`是`的意思，当然编程时写`系`也是能运行的。  
同样的，`唔係`就是`不是`的意思， `定係`就是`还是`的意思......

## 如果 ... 嘅话 ...
这条语句不用解释吧? 你只要知道`嘅`的意思是`的`，那么理解这个语句比呼吸还要简单!  

## 落操场玩跑步 ... 玩到 ... 为止
这个语句可以让计算机van起跑步(循环)来, `玩到 ... 为止`之间的是循环的条件

## 掟个 ... 来睇下
这个语句的作用是抛出一个异常。  
通过提手旁不难猜出`掟`有`仍`或`丢`的意思，真是一个有动作的句子，哈哈!  

## 退出
exit有3种用法: 
* 收工 
* 辛苦晒啦
* 同我躝  

第一个是`下班`的意思, 第二个则有对计算机表示感谢的意思，而第三个中的`躝`是滚的意思，这个语句最好不用，除非你对计算机实在是恨之入骨了。。。  

## 谂下
`谂`在粤语中的意思是`想`，我们的计算机已经是能够思考的物体了，用了这条语句会绞尽脑汁帮你作出判断。  

## 执嘢 ... 揾到 ... 执手尾
想象一下你在房间里收拾，用粤语说就是`执嘢`, 到你意外找到(`揾到`)东西时, 你有两个选择: 丢 或 不丢, 你必须要在其中作出决定，这就是`执手尾`了.  

## 要做咩 ... 搞掂
看过SICP都知道，函数就是定义一个抽象的计算过程.  
一个个函数代表一个个功能，所以用`要做咩`(要做什么)直观地告诉计算机该函数的抽象过程, 再用`搞掂`(搞定)来做结束语

## 佢
`佢`在粤语的意思是`它`，这适用于来描述一个对象，用`佢嘅`(它的)来构造属性，用`佢识得`(它会)就可以构造类的方法, `老豆`就是`老爸`的意思，用于描述继承关系，当然也支持多继承，毕竟爸爸也可以有好多个嘛:
```
咩系 |duck|?
    佢个老豆叫 |object|
    佢嘅 |性别| 系 "公"
    佢识得 |游水| -> {
        畀我睇下 "Duck is swimming" 点样先？
    }
明白未啊?
```
最后用`明白未啊`做结束语，这时计算机就会开始接受你介绍给它的对象,记得对象描述要丰富点哦！谁不喜欢`Outgoing`类型的对象呢？哈哈！

## 最后
恭喜你，你已解锁新技能 -- 用粤语写代码，虽然实际中不会用粤语写代码，但是空闲时玩一下粤语编程，难道不是件乐事吗?